@@ -174,18 +174,12 @@ impl Yozuk {
 
 #[derive(Default)]
 pub struct YozukBuilder {
-    env: Environment,
     config: Config,
     i18n: I18n,
     redirections: Vec<(Vec<Token>, Vec<String>)>,
 }
 
 impl YozukBuilder {
-    pub fn set_env(mut self, env: Environment) -> Self {
-        self.env = env;
-        self
-    }
-
     pub fn set_config(mut self, config: Config) -> Self {
         self.config = config;
         self
@@ -212,15 +206,9 @@ impl YozukBuilder {
 
     pub fn build(self) -> Yozuk {
         let model = ModelSet::from_data(MODEL_DATA).unwrap();
-        let build_info = BuildInfo {
-            version: env!("CARGO_PKG_VERSION").into(),
-            commit: env!("GIT_COMMIT").into(),
-            rustc: env!("RUSTC_VERSION").into(),
-            timestamp: env!("BUILD_TIMESTAMP").into(),
-        };
-        let env = Environment::new()
-            .build_info("yozuk", build_info)
-            .merge(self.env);
+        let build_info = concat!(r#"{"version": ""#, env!("CARGO_PKG_VERSION"), r#""}"#);
+
+        let env = Environment::new().build_info(build_info);
 
         #[cfg(feature = "rayon")]
         let iter = skill::SKILLS.par_iter();
