@@ -1,4 +1,4 @@
-#![cfg(all(feature = "modelgen", feature = "yozuk-skill-bitcoin"))]
+#![cfg(feature = "yozuk-skill-bitcoin")]
 
 mod common;
 use common::cmd;
@@ -7,7 +7,7 @@ use yozuk_sdk::prelude::*;
 #[test]
 fn test_address_generation() {
     assert_eq!(
-        cmd(tk!(["BTC"])),
+        cmd(tk!(["btc"])),
         CommandArgs::new().add_args(["yozuk-skill-bitcoin"])
     );
     assert_eq!(
